@@ -9,7 +9,7 @@ use ast_grep_core::{NodeMatch, StrDoc};
 use clap::Args;
 use ignore::WalkParallel;
 
-use crate::config::{read_rule_file, ProjectConfig};
+use crate::config::{read_rule_file, with_rule_stats, ProjectConfig};
 use crate::lang::SgLang;
 use crate::print::{
   CloudPrinter, ColoredPrinter, Diff, InteractivePrinter, JSONPrinter, Platform, Printer,
@@ -18,7 +18,7 @@ use crate::print::{
 use crate::utils::ErrorContext as EC;
 use crate::utils::RuleOverwrite;
 use crate::utils::{filter_file_interactive, ContextArgs, InputArgs, OutputArgs, OverwriteArgs};
-use crate::utils::{FileTrace, RuleTrace, ScanTrace};
+use crate::utils::{FileTrace, ScanTrace};
 use crate::utils::{Items, PathWorker, StdInWorker, Worker};
 
 type AstGrep = ast_grep_core::AstGrep<StrDoc<SgLang>>;
@@ -110,24 +110,21 @@ struct ScanWithConfig<Printer> {
 }
 impl<P: Printer> ScanWithConfig<P> {
   fn try_new(arg: ScanArg, printer: P, project: Result<ProjectConfig>) -> Result<Self> {
-    let mut rule_trace = RuleTrace::default();
     let overwrite = RuleOverwrite::new(&arg.overwrite)?;
-    let unused_suppression_rule = unused_supression_rule_config(&overwrite);
-    let configs = if let Some(path) = &arg.rule {
+    let unused_suppression_rule = unused_suppression_rule_config(&overwrite);
+    let (configs, rule_trace) = if let Some(path) = &arg.rule {
       let rules = read_rule_file(path, None)?;
-      RuleCollection::try_new(rules).context(EC::GlobPattern)?
+      with_rule_stats(rules)?
     } else if let Some(text) = &arg.inline_rules {
       let rules = from_yaml_string(text, &Default::default())
         .with_context(|| EC::ParseRule("INLINE_RULES".into()))?;
-      RuleCollection::try_new(rules).context(EC::GlobPattern)?
+      with_rule_stats(rules)?
     } else {
       // NOTE: only query project here since -r does not need project
       let project_config = project?;
-      let (configs, r_stats) = project_config.find_rules(overwrite)?;
-      rule_trace = r_stats;
-      configs
+      project_config.find_rules(overwrite)?
     };
-    let trace = arg.output.tracing.scan_trace(rule_trace);
+    let trace = arg.output.inspect.scan_trace(rule_trace);
     Ok(Self {
       arg,
       printer,
@@ -168,7 +165,7 @@ impl<P: Printer> Worker for ScanWithConfig<P> {
         }
         match_rule_on_file(path, matches, rule, &file_content, &self.printer)?;
       }
-      print_unused_suppressions(
+      error_count += print_unused_suppressions(
         path,
         scanned.unused_suppressions,
         &self.unused_suppression_rule,
@@ -177,9 +174,7 @@ impl<P: Printer> Worker for ScanWithConfig<P> {
       )?;
     }
     self.printer.after_print()?;
-    if let Some(trace) = self.trace.print(self.arg.output.json.is_some()) {
-      eprintln!("{}", trace);
-    }
+    self.trace.print()?;
     if error_count > 0 {
       Err(anyhow::anyhow!(EC::DiagnosticError(error_count)))
     } else {
@@ -188,7 +183,7 @@ impl<P: Printer> Worker for ScanWithConfig<P> {
   }
 }
 
-fn unused_supression_rule_config(overwrite: &RuleOverwrite) -> RuleConfig<SgLang> {
+fn unused_suppression_rule_config(overwrite: &RuleOverwrite) -> RuleConfig<SgLang> {
   let rule: SerializableRule = serde_json::from_str(r#"{"pattern": "a"}"#).unwrap();
   let core = SerializableRuleCore {
     rule,
@@ -223,8 +218,15 @@ fn print_unused_suppressions(
   rule_config: &RuleConfig<SgLang>,
   file_content: &String,
   printer: &impl Printer,
-) -> Result<()> {
-  match_rule_on_file(path, matches, rule_config, file_content, printer)
+) -> Result<usize> {
+  let count = match rule_config.severity {
+    Severity::Error => matches.len(),
+    // skip printing turned-off rule
+    Severity::Off => return Ok(0),
+    _ => 0,
+  };
+  match_rule_on_file(path, matches, rule_config, file_content, printer)?;
+  Ok(count)
 }
 
 impl<P: Printer> PathWorker for ScanWithConfig<P> {
@@ -235,7 +237,7 @@ impl<P: Printer> PathWorker for ScanWithConfig<P> {
     self.arg.input.walk()
   }
   fn produce_item(&self, path: &Path) -> Option<Vec<Self::Item>> {
-    filter_file_interactive(path, &self.configs)
+    filter_file_interactive(path, &self.configs, &self.trace)
   }
 }
 
@@ -291,7 +293,7 @@ impl<P: Printer> StdInWorker for ScanWithRule<P> {
     let combined = CombinedScan::new(self.rules.iter().collect());
     let grep = lang.ast_grep(src);
     let pre_scan = combined.find(&grep);
-    if !pre_scan.hit_set.is_empty() {
+    if !pre_scan.is_empty() {
       Some((PathBuf::from("STDIN"), grep, pre_scan))
     } else {
       None
@@ -392,7 +394,7 @@ rule:
         json: None,
         update_all: false,
         color: ColorArg::Never,
-        tracing: Default::default(),
+        inspect: Default::default(),
       },
       context: ContextArgs {
         before: 0,
