@@ -1,7 +1,7 @@
 use crate::lang::SgLang;
 use crate::print::{ColorArg, JsonStyle};
 use crate::utils::ErrorContext as EC;
-use crate::utils::Tracing;
+use crate::utils::Granularity;
 
 use anyhow::{Context, Result};
 use clap::{Args, ValueEnum};
@@ -147,13 +147,13 @@ pub struct OutputArgs {
   #[clap(long, default_value = "auto", value_name = "WHEN")]
   pub color: ColorArg,
 
-  /// Show tracing information for file/rule discovery and scanning.
+  /// Inspect information for file/rule discovery and scanning.
   ///
-  /// This flag helps user to inspect ast-grep's internal filtering of files and rules.
-  /// tracing will output how many and why files and rules are scanned and skipped.
-  /// tracing information outputs to stderr and does not affect the result of the search.
-  #[clap(long, default_value = "nothing", value_name = "LEVEL")]
-  pub tracing: Tracing,
+  /// This flag helps user to observe ast-grep's internal filtering of files and rules.
+  /// Inspection will output how many and why files and rules are scanned and skipped.
+  /// Inspection outputs to stderr and does not affect the result of the search.
+  #[clap(long, default_value = "nothing", value_name = "GRANULARITY")]
+  pub inspect: Granularity,
 }
 
 impl OutputArgs {
