@@ -136,3 +136,43 @@ fn test_sg_scan_html() -> Result<()> {
     .stdout(contains("rule-3").not());
   Ok(())
 }
+
+#[test]
+fn test_scan_unused_suppression() -> Result<()> {
+  let dir = create_test_files([
+    ("sgconfig.yml", CONFIG),
+    ("rules/rule.yml", RULE1),
+    ("test.ts", "None(123) // ast-grep-ignore"),
+  ])?;
+  Command::cargo_bin("sg")?
+    .current_dir(dir.path())
+    .args(["scan"])
+    .assert()
+    .success()
+    .stdout(contains("unused-suppression"));
+  Ok(())
+}
+
+#[test]
+fn test_severity_override() -> Result<()> {
+  let dir = setup()?;
+  Command::cargo_bin("sg")?
+    .current_dir(dir.path())
+    .args(["scan", "--error"])
+    .assert()
+    .failure()
+    .stdout(contains("error"));
+  Command::cargo_bin("sg")?
+    .current_dir(dir.path())
+    .args(["scan", "--error=on-rule"])
+    .assert()
+    .failure()
+    .stdout(contains("error"));
+  Command::cargo_bin("sg")?
+    .current_dir(dir.path())
+    .args(["scan", "--error=not-exist"])
+    .assert()
+    .success()
+    .stdout(contains("warning"));
+  Ok(())
+}
