@@ -22,7 +22,6 @@ pub enum Lang {
   C,
   Cpp,
   CSharp,
-  Dart,
   Go,
   Elixir,
   Haskell,
@@ -54,7 +53,6 @@ impl From<Lang> for SupportLang {
       F::C => S::C,
       F::Cpp => S::Cpp,
       F::CSharp => S::CSharp,
-      F::Dart => S::Dart,
       F::Go => S::Go,
       F::Elixir => S::Elixir,
       F::Haskell => S::Haskell,
@@ -88,7 +86,6 @@ impl From<SupportLang> for Lang {
       S::C => F::C,
       S::Cpp => F::Cpp,
       S::CSharp => F::CSharp,
-      S::Dart => F::Dart,
       S::Go => F::Go,
       S::Elixir => F::Elixir,
       S::Haskell => F::Haskell,
